@@ -1,4 +1,4 @@
 from .channel_steepness import SteepnessFinder
 
 
-__all__ = ['SteepnessFinder', ]
+__all__ = ["SteepnessFinder"]
