@@ -15,10 +15,11 @@ from .watershed import (
     get_watershed_outlet,
     get_watershed_masks,
 )
-from .stable_priority_queue import StablePriorityQueue
 
+from .add_halo import add_halo
 
 __all__ = [
+    "add_halo",
     "count_repeated_values",
     "track_source",
     "convert_arc_flow_directions_to_landlab_node_ids",
@@ -28,5 +29,4 @@ __all__ = [
     "get_watershed_nodes",
     "get_watershed_outlet",
     "get_watershed_masks",
-    "StablePriorityQueue"
 ]
